==> nushell-0.103.0-crates.tar.xz: cargo_home/gentoo/polars-plan-0.46.0/src/plans/optimizer/projection_pushdown/hconcat.rs <==
use super::*;

#[allow(clippy::too_many_arguments)]
pub(super) fn process_hconcat(
    proj_pd: &mut ProjectionPushDown,
    inputs: Vec<Node>,
    schema: SchemaRef,
    options: HConcatOptions,
    ctx: ProjectionContext,
    lp_arena: &mut Arena<IR>,
    expr_arena: &mut Arena<AExpr>,
) -> PolarsResult<IR> {
    // When applying projection pushdown to horizontal concatenation,
    // we apply pushdown to all of the inputs using the subset of accumulated projections relevant to each input,
    // then rebuild the concatenated schema.

    let schema = if ctx.acc_projections.is_empty() {
        schema
    } else {
        let mut remaining_projections: PlHashSet<_> = ctx.acc_projections.into_iter().collect();

        for input in inputs.iter() {
            let mut input_pushdown = Vec::new();
            let input_schema = lp_arena.get(*input).schema(lp_arena);

            for proj in remaining_projections.iter() {
                if check_input_column_node(*proj, input_schema.as_ref(), expr_arena) {
                    input_pushdown.push(*proj);
                }
            }

            let mut input_names = PlHashSet::new();
            for proj in &input_pushdown {
                remaining_projections.remove(proj);
                for name in aexpr_to_leaf_names(proj.0, expr_arena) {
                    input_names.insert(name);
                }
            }
            let ctx = ProjectionContext::new(input_pushdown, input_names, ctx.projections_seen);
            proj_pd.pushdown_and_assign(*input, ctx, lp_arena, expr_arena)?;
        }

        let mut schemas = Vec::with_capacity(inputs.len());
        for input in inputs.iter() {
            let schema = lp_arena.get(*input).schema(lp_arena).into_owned();
            schemas.push(schema);
        }
        let new_schema = merge_schemas(&schemas)?;
        Arc::new(new_schema)
    };

    Ok(IR::HConcat {
        inputs,
        schema,
        options,
    })
}

==> nushell-0.108.0-crates.tar.xz: cargo_home/gentoo/polars-plan-0.51.0/src/plans/optimizer/projection_pushdown/hconcat.rs <==
use super::*;

#[allow(clippy::too_many_arguments)]
pub(super) fn process_hconcat(
    proj_pd: &mut ProjectionPushDown,
    inputs: Vec<Node>,
    schema: SchemaRef,
    options: HConcatOptions,
    ctx: ProjectionContext,
    lp_arena: &mut Arena<IR>,
    expr_arena: &mut Arena<AExpr>,
) -> PolarsResult<IR> {
    // When applying projection pushdown to horizontal concatenation,
    // we apply pushdown to all of the inputs using the subset of accumulated projections relevant to each input,
    // then rebuild the concatenated schema.

    let schema = if ctx.acc_projections.is_empty() {
        schema
    } else {
        let mut remaining_projections: PlHashSet<_> = ctx.acc_projections.into_iter().collect();

        for input in inputs.iter() {
            let mut input_pushdown = Vec::new();
            let input_schema = lp_arena.get(*input).schema(lp_arena);

            for proj in remaining_projections.iter() {
                if check_input_column_node(*proj, input_schema.as_ref(), expr_arena) {
                    input_pushdown.push(*proj);
                }
            }

            let mut input_names = PlHashSet::new();
            for proj in &input_pushdown {
                remaining_projections.remove(proj);
                for name in aexpr_to_leaf_names(proj.0, expr_arena) {
                    input_names.insert(name);
                }
            }
            let ctx = ProjectionContext::new(input_pushdown, input_names, ctx.inner);
            proj_pd.pushdown_and_assign(*input, ctx, lp_arena, expr_arena)?;
        }

        let mut schemas = Vec::with_capacity(inputs.len());
        for input in inputs.iter() {
            let schema = lp_arena.get(*input).schema(lp_arena).into_owned();
            schemas.push(schema);
        }
        let new_schema = merge_schemas(&schemas)?;
        Arc::new(new_schema)
    };

    Ok(IR::HConcat {
        inputs,
        schema,
        options,
    })
}
